/// Copyright (c) 2012 Ecma International.  All rights reserved. 
/// Ecma International makes this code available under the terms and conditions set
/// forth on http://hg.ecmascript.org/tests/test262/raw-file/tip/LICENSE (the 
/// "Use Terms").   Any redistribution of this code must retain the above 
/// copyright and this notice and otherwise comply with the Use Terms.
/**
 * @path ch11/11.1/11.1.4/11.1.4-0.js
 * @description elements elided at the end of an array do not contribute to its length
 */


function testcase() {
  var a = [,];
  if (a.length === 1) {
    return true;
  }
 }
runTestCase(testcase);
